---
label: ULTRA_MEGA_SORT_2000
dockerfile:
wrapper:
notes: Not yet incorporated into SpikeForest
website: https://neurophysics.ucsd.edu/software.php
source_code:
authors: Daniel N. Hill, Samar B. Mehta, and David Kleinfeld
doi:
---

# ULTRA_MEGA_SORT_2000

## Description

## References
